VolumeSettings class

Configuration for alarm volume and fading.

Constructors

VolumeSettings({double? volume, Duration? fadeDuration, List<VolumeFadeStep> fadeSteps = const [], bool volumeEnforced = false})
Creates a new VolumeSettings instance.
const
VolumeSettings.fromMap(Map<String, dynamic> map)
Creates a VolumeSettings from a map.
factory

Properties

fadeDuration Duration?
Duration over which to fade the alarm ringtone. If provided, volume starts at 0 and reaches volume or 1.0 linearly over this duration.
final
fadeSteps List<VolumeFadeStep>
Controls how the alarm volume will fade over time with custom steps. If provided, fadeDuration is ignored.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
volume double?
Sets system volume level (0.0 to 1.0). Reverts on alarm stop. Defaults to current volume if null.
final
volumeEnforced bool
Automatically resets to the target alarm volume if the user attempts to adjust it.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this VolumeSettings to a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited