getLaunchAlarm method
Retrieves the alarm that triggered app launch, if any.
Implementation
Future<AlarmModel?> getLaunchAlarm() {
throw UnimplementedError('getLaunchAlarm() has not been implemented.');
}
Retrieves the alarm that triggered app launch, if any.
Future<AlarmModel?> getLaunchAlarm() {
throw UnimplementedError('getLaunchAlarm() has not been implemented.');
}